@@ -1,5 +1,5 @@
 /* GIMP Plug-in Template
- * Copyright (C) 2000  Michael Natterer <mitch@gimp.org> (the "Author").
+ * Copyright (C) 2000-2004  Michael Natterer <mitch@gimp.org> (the "Author").
  * All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -35,9 +35,6 @@
 
 #include "plugin-intl.h"
 
-#include "pixmaps/zoom_in.xpm"
-#include "pixmaps/zoom_out.xpm"
-
 
 /*  Constants  */
 
@@ -48,21 +45,13 @@
 
 /*  Local function prototypes  */
 
-static void       dialog_pixmap_callback            (GtkWidget *widget,
-						     gpointer   data);
-static void       dialog_layer_menu_callback        (gint32     id,
-						     gpointer   data);
-static void       dialog_image_menu_callback        (gint32     id,
-						     gpointer   data);
-static gboolean   dialog_rgb_images_constraint_func (gint32     image_id,
-						     gint32     drawable_id,
-						     gpointer   data);
+static gboolean   dialog_image_constraint_func (gint32    image_id,
+                                                gpointer  data);
 
 
 /*  Local variables  */
 
 static PlugInUIVals *ui_state = NULL;
-static GtkWidget    *pixmap   = NULL;
 
 
 /*  Public functions  */
@@ -81,12 +70,8 @@ dialog (gint32              image_ID,
   GtkWidget *table;
   GtkWidget *hbox;
   GtkWidget *hbox2;
-  GtkWidget *label;
-  GtkWidget *button;
-  GtkWidget *optionmenu;
   GtkWidget *coordinates;
-  GtkWidget *menu;
-  GtkWidget *sep;
+  GtkWidget *combo;
   GtkObject *adj;
   gint       row;
   gboolean   run = FALSE;
@@ -106,19 +91,18 @@ dialog (gint32              image_ID,
 
 			 NULL);
 
-  main_vbox = gtk_vbox_new (FALSE, 4);
-  gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 6);
+  main_vbox = gtk_vbox_new (FALSE, 12);
+  gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 12);
   gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dlg)->vbox), main_vbox);
 
   /*  gimp_scale_entry_new() examples  */
 
-  frame = gtk_frame_new (_("ScaleEntry Examples"));
+  frame = gimp_frame_new (_("ScaleEntry Examples"));
   gtk_box_pack_start (GTK_BOX (main_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
   table = gtk_table_new (3, 3, FALSE);
-  gtk_container_set_border_width (GTK_CONTAINER (table), 4);
-  gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 6);
   gtk_table_set_row_spacings (GTK_TABLE (table), 2);
   gtk_container_add (GTK_CONTAINER (frame), table);
   gtk_widget_show (table);
@@ -154,11 +138,10 @@ dialog (gint32              image_ID,
 
   /*  gimp_random_seed_new() example  */
 
-  frame = gtk_frame_new (_("A Random Seed Entry"));
+  frame = gimp_frame_new (_("A Random Seed Entry"));
   gtk_box_pack_start (GTK_BOX (main_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
-  hbox = gtk_hbox_new (FALSE, 4);
-  gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
+  hbox = gtk_hbox_new (FALSE, 6);
   gtk_container_add (GTK_CONTAINER (frame), hbox);
   gtk_widget_show (hbox);
 
@@ -168,50 +151,9 @@ dialog (gint32              image_ID,
   gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, FALSE, 0);
   gtk_widget_show (hbox2);
 
-  /*  gimp_pixmap_new() and gimp_pixmap_button_new() examples  */
-
-  frame = gtk_frame_new (_("Pixmap Examples"));
-  gtk_box_pack_start (GTK_BOX (main_vbox), frame, FALSE, FALSE, 0);
-  gtk_widget_show (frame);
-
-  hbox = gtk_hbox_new (FALSE, 4);
-  gtk_container_set_border_width (GTK_CONTAINER (hbox), 4);
-  gtk_container_add (GTK_CONTAINER (frame), hbox);
-  gtk_widget_show (hbox);
-
-  label = gtk_label_new (_("Pixmap Buttons:"));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_widget_show (label);
-
-  button = gimp_pixmap_button_new (zoom_in_xpm, NULL);
-  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-  g_signal_connect (button, "clicked",
-                    G_CALLBACK (dialog_pixmap_callback),
-                    zoom_in_xpm);
-  gtk_widget_show (button);
-
-  button = gimp_pixmap_button_new (zoom_out_xpm, _("With Text"));
-  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-  g_signal_connect (button, "clicked",
-                    G_CALLBACK (dialog_pixmap_callback),
-                    zoom_out_xpm);
-  gtk_widget_show (button);
-
-  sep = gtk_vseparator_new ();
-  gtk_box_pack_start (GTK_BOX (hbox), sep, TRUE, TRUE, 0);
-  gtk_widget_show (sep);
-
-  pixmap = gimp_pixmap_new (zoom_in_xpm);
-  gtk_box_pack_end (GTK_BOX (hbox), pixmap, FALSE, FALSE, 0);
-  gtk_widget_show (pixmap);
-
-  label = gtk_label_new (_("Plain Pixmap:"));
-  gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_widget_show (label);
-
   /*  gimp_coordinates_new() example  */
 
-  frame = gtk_frame_new (_("A GimpCoordinates Widget\n"
+  frame = gimp_frame_new (_("A GimpCoordinates Widget\n"
 			   "Initialized with the Drawable's Size"));
   gtk_box_pack_start (GTK_BOX (main_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
@@ -241,7 +183,7 @@ dialog (gint32              image_ID,
 
   /*  Image and drawable menus  */
 
-  frame = gtk_frame_new (_("Image and Drawable Menu Examples"));
+  frame = gimp_frame_new (_("Image and Drawable Menu Examples"));
   gtk_box_pack_start (GTK_BOX (main_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
@@ -254,27 +196,21 @@ dialog (gint32              image_ID,
 
   row = 0;
 
-  menu = gimp_layer_menu_new (NULL,
-			      dialog_layer_menu_callback,
-			      drawable_vals,
-			      drawable->drawable_id);
-  optionmenu = gtk_option_menu_new ();
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu), menu);
+  combo = gimp_layer_combo_box_new (NULL, NULL);
+  gimp_int_combo_box_connect (GIMP_INT_COMBO_BOX (combo), drawable->drawable_id,
+                              G_CALLBACK (gimp_int_combo_box_get_active),
+                              &drawable_vals->drawable_id);
 
   gimp_table_attach_aligned (GTK_TABLE (table), 0, row++,
-			     _("Layers:"), 1.0, 0.5,
-			     optionmenu, 1, TRUE);
+			     _("Layers:"), 0.0, 0.5, combo, 1, FALSE);
 
-  menu = gimp_image_menu_new (dialog_rgb_images_constraint_func,
-			      dialog_image_menu_callback,
-			      image_vals,
-			      image_ID);
-  optionmenu = gtk_option_menu_new ();
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu), menu);
+  combo = gimp_image_combo_box_new (dialog_image_constraint_func, NULL);
+  gimp_int_combo_box_connect (GIMP_INT_COMBO_BOX (combo), image_ID,
+                              G_CALLBACK (gimp_int_combo_box_get_active),
+                              &image_vals->image_id);
 
   gimp_table_attach_aligned (GTK_TABLE (table), 0, row++,
-			     _("RGB Images:"), 1.0, 0.5,
-			     optionmenu, 1, TRUE);
+			     _("RGB Images:"), 0.0, 0.5, combo, 1, FALSE);
 
   /*  Show the main containers  */
 
@@ -298,36 +234,9 @@ dialog (gint32              image_ID,
 
 /*  Private functions  */
 
-static void
-dialog_pixmap_callback (GtkWidget *widget,
-			gpointer   data)
-{
-  if (pixmap)
-    gimp_pixmap_set (GIMP_PIXMAP (pixmap), data);
-}
-
-static void
-dialog_layer_menu_callback (gint32   id,
-			    gpointer data)
-{
-  PlugInDrawableVals *drawable_vals = (PlugInDrawableVals *) data;
-
-  drawable_vals->drawable_id = id;
-}
-
-static void
-dialog_image_menu_callback (gint32   id,
-			    gpointer data)
-{
-  PlugInImageVals *image_vals = (PlugInImageVals *) data;
-
-  image_vals->image_id = id;
-}
-
 static gboolean
-dialog_rgb_images_constraint_func (gint32   image_id,
-				   gint32   drawable_id,
-				   gpointer data)
+dialog_image_constraint_func (gint32    image_id,
+                              gpointer  data)
 {
   return (gimp_image_base_type (image_id) == GIMP_RGB);
 }
