@@ -134,11 +134,13 @@ query (void)
 			  "Michael Natterer <mitch@gimp.org>",
 			  "Michael Natterer <mitch@gimp.org>",
 			  "2000-2004",
-			  N_("<Image>/Filters/Misc/Plug-In Template..."),
+			  N_("Plug-In Template..."),
 			  "RGB*, GRAY*, INDEXED*",
 			  GIMP_PLUGIN,
 			  G_N_ELEMENTS (args), 0,
 			  args, NULL);
+
+  gimp_plugin_menu_register (PROCEDURE_NAME, "<Image>/Filters/Misc/");
 }
 
 static void
