@@ -8,7 +8,7 @@
  * the rights to use, copy, modify, merge, publish, distribute, sublicense,
  * and/or sell copies of the Software, and to permit persons to whom the
  * Software is furnished to do so, subject to the following conditions:
- * 
+ *
  * The above copyright notice and this permission notice shall be included
  * in all copies or substantial portions of the Software.
  *
@@ -18,7 +18,7 @@
  * THE AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
  * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
- * 
+ *
  * Except as contained in this notice, the name of the Author of the
  * Software shall not be used in advertising or otherwise to promote the
  * sale, use or other dealings in this Software without prior written
@@ -31,25 +31,26 @@
 
 typedef struct
 {
-  gint     dummy1;
-  gint     dummy2;
-  gint     dummy3;
-  guint    seed;
+  gint      dummy1;
+  gint      dummy2;
+  gint      dummy3;
+  guint     seed;
+  gboolean  random_seed;
 } PlugInVals;
 
 typedef struct
 {
-  gint32   image_id;
+  gint32    image_id;
 } PlugInImageVals;
 
 typedef struct
 {
-  gint32   drawable_id;
+  gint32    drawable_id;
 } PlugInDrawableVals;
 
 typedef struct
 {
-  gboolean chain_active;
+  gboolean  chain_active;
 } PlugInUIVals;
 
 
